#!/bin/bash
#
# Banish 1.4.7 for IPCop 1.4.18+
# Version 1.4.7
# Banish installation script
#
# SID Solutions
# http://sidsolutions.net
# Copyright (c) 2005/07/10 Sid McLaurin 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# $Id: install_Banish.sh,v 1.4.7 2008/03/18 22:13 Sid McLaurin

# Set Version Number
VERSION="1.4.7"

# Print install message to console

echo -e "\nSID Solutions\n"
sleep 0.5
echo -e "S\033[1;34molid\033[0m I\033[1;34mnnovative\033[0m D\033[1;34mesigned\033[0m Solutions\n"
echo "Providing tomorrow's solutions, today."
echo
sleep 1

# Start Installation
echo -e "\033[1;32mStarting Banish 1.4.7 installation \033[0m"
/usr/bin/logger -t "banish" "Starting Banish 1.4.7 Installation"
echo

# Check if files extracted to /tmp:
echo -e "Checking if files extracted to /tmp.\c"
if [ ! -d /tmp/banish-1.4.7 ] ; 
	then
    	echo
    	echo
    	echo -e "\033[1;31mError!"
    	echo
    	echo "The files are not extracted to /tmp"
    	echo -e "Please extract banish-1.4.7.tar.gz in /tmp!!\033[0m"
    	/usr/bin/logger -t "banish" "Banish not extracted to /tmp, Banish installation aborted"
    	echo
     	exit 1
	else
		echo -e "...OK!"
fi
 

# Check if installation files exits
echo -e "Checking files......................\c"
if [ ! -f md5-check -o \
	  ! -f install_Banish.sh -o \
	  ! -f files.tar.gz ]
	then
		echo -e	"\033[1;31mError!"
	 	echo
	 	echo "One of the following files are missing"
	 	echo "md5-check"
	 	echo "install_Banish.sh"
	 	echo "files.tar.gz"
	 	echo
	 	echo -e "Please download file again. \033[0m"
	 	/usr/bin/logger -t "banish" "Banish file check failed, Banish installation aborted"
	 	echo
	 	exit 1
	 else
		echo "...OK!"
fi	 

# Perform MD5SUM Check
echo -e "Checking md5sum.....................\c"

# Run check and capture output
md5sum -c md5-check >test 2>&1
WARNING=`cat test|grep FAILED`

if [ "$WARNING" ]
	 then
	 echo -e "\033[1;31mError!"
	 echo
	 echo -e "WARNING! MD5-check failed, installation aborted."
	 echo -e "Please download installation file again. \033[0m"
	 /usr/bin/logger -t "banish" "MD5-check failed, Banish installation aborted"
	 echo
	 exit 1
	else
	 echo "...OK!"
fi

# Check for previous versions
if [ -x /usr/local/bin/uninstall_Banish.sh ]
   then
	echo
	echo -e "\033[1;33mPrevious installation detected \033[0m"
	
	# Backup Banish configuration files
	if [ -e /var/ipcop/Banish/Banish_config ]
		then
		
		# Get current installed Banish Version
		BANVERSION=`cat /usr/local/bin/uninstall_Banish.sh|grep Version|awk ' { print $3 } '`
		
		# See if this will be an upgrade
		UPGRADE=`echo $VERSION $BANVERSION|awk '{ print ($1 > $2) ? "true" : "false" }'`
   		
		if [ "$UPGRADE" = "true" ]
			then
				echo
				echo -e "\033[1;33mUninstalling first \033[0m"
				cp -p /var/ipcop/Banish/Banish_config .
				cp -p /var/ipcop/Banish/ip_Banishlist .
				if [ -e /var/ipcop/Banish/Banish_settings ]
					then
						cp -p /var/ipcop/Banish/Banish_settings .
				fi
				/usr/local/bin/uninstall_Banish.sh
				echo -e "\033[1;33mContinuing with install \033[0m"
			else
				echo
				echo -e "\033[1;33mYou have the current version of banish Banish installed"
				echo -e "To reinstall, run /usr/local/bin/uninstall_Banish.sh first"
				/usr/bin/logger -t "banish" "Current version of banish Banish already installed"
				echo -e "Exiting installation \033[0m"
				echo
				exit 1
		fi
	fi			
fi

# Check for GeoIP
perl -MGeo::IP::PurePerl -e " " >geo_test 2>&1
GEOIP=`cat geo_test|grep "Can't"`

# Backup files
echo -e "Backing up files.....................\c"

if [ -d /SID_Solutions ]
   then
		/bin/mkdir /SID_Solutions/Banish >/dev/null 2>&1
   else
		/bin/mkdir /SID_Solutions >/dev/null 2>&1
		/bin/mkdir /SID_Solutions/Banish >/dev/null 2>&1
fi	
/bin/cp -p /var/ipcop/langs/en.pl /SID_Solutions/Banish/en.pl.bak
/bin/cp -p /var/ipcop/header.pl /SID_Solutions/Banish/header.pl.bak
/bin/cp -p /home/httpd/cgi-bin/ipinfo.cgi /SID_Solutions/Banish/ipinfo.cgi.bak
/bin/cp -p /home/httpd/cgi-bin/logs.cgi/firewalllog.dat /SID_Solutions/Banish/firewalllog.dat.bak
/bin/cp -p /home/httpd/cgi-bin/logs.cgi/log.dat /SID_Solutions/Banish/log.dat.bak
/bin/cp -p /etc/rc.d/rc.local /SID_Solutions/Banish/rc.local.bak
echo "Done!"

# Extract files
echo -e "Extracting files.....................\c"
tar xzf files.tar.gz
echo "Done!"

# Install Banish files
echo -e "Installing system files..............\c"

# Make Banish image directory
/bin/mkdir /home/httpd/html/images/Banish >/dev/null 2>&1

# Install System files
/bin/cp -p Banish/usr/local/bin/* /usr/local/bin/

if [ -z "$GEOIP" ]
	then
		/bin/cp -p Banish/home/httpd/cgi-bin/BanishGeo.cgi /home/httpd/cgi-bin/Banish.cgi
	else
		/bin/cp -p Banish/home/httpd/cgi-bin/Banish.cgi /home/httpd/cgi-bin/Banish.cgi
fi
/bin/cp -p Banish/home/httpd/cgi-bin/Banish_Credits.cgi /home/httpd/cgi-bin/Banish_Credits.cgi
/bin/cp -p Banish/home/httpd/cgi-bin/Banish_Settings.cgi /home/httpd/cgi-bin/Banish_Settings.cgi
/bin/cp -p Banish/home/httpd/cgi-bin/logs.cgi/Banishlog.dat /home/httpd/cgi-bin/logs.cgi/Banishlog.dat
/bin/cp -p Banish/home/httpd/html/images/* /home/httpd/html/images/Banish/
/bin/cp -p Banish/etc/rc.d/rc.Banish /etc/rc.d/rc.Banish

# Use previous configuration files if they exist
if [ -s Banish_config ]
   	then
   		/bin/mkdir /var/ipcop/Banish
		/bin/cp -p Banish_config /var/ipcop/Banish/
		/bin/cp -p ip_Banishlist /var/ipcop/Banish/
		/bin/cp -p Banish/var/ipcop/Banish/Banish-functions.pl /var/ipcop/Banish/
		if [ -s /var/ipcop/Banish/rm_Banishlist ]
			then
				/bin/cp -p ip_Banishlist /var/ipcop/Banish/rm_Banishlist
   		else
   			/bin/cp -p Banish/var/ipcop/Banish/rm_Banishlist /var/ipcop/Banish/
		fi
		if [ -s Banish_settings ]
			then
				/bin/cp -p Banish_settings /var/ipcop/Banish/
		else
			/bin/cp -p Banish/var/ipcop/Banish/Banish_settings /var/ipcop/Banish/
		fi
   	else
		# Make Banish directory and install files
		/bin/mkdir /var/ipcop/Banish
		/bin/cp -rp Banish/var/ipcop/Banish/* /var/ipcop/Banish/
fi

echo "Done!"

# Appending files
echo -e "Appending to files...................\c"

# Add entry to header.pl
/bin/cat /var/ipcop/header.pl | sed -e '/7.mainlogs.*subMenu.*2.*1/ r Banish/header.Banish'>header.pl.tmp
/bin/cp -p header.pl.tmp /var/ipcop/header.pl
/bin/rm header.pl.tmp

# Add Languages
# English
/bin/cp Banish/Banish.en.pl /var/ipcop/addon-lang/Banish.en.pl

# Deutsch
/bin/cp Banish/Banish.de.pl /var/ipcop/addon-lang/Banish.de.pl

# French
/bin/cp Banish/Banish.fr.pl /var/ipcop/addon-lang/Banish.fr.pl

# Italian
/bin/cp Banish/Banish.it.pl /var/ipcop/addon-lang/Banish.it.pl

# Spanish
/bin/cp Banish/Banish.es.pl /var/ipcop/addon-lang/Banish.es.pl

# Portuguese
/bin/cp Banish/Banish.pt.pl /var/ipcop/addon-lang/Banish.pt.pl

# Netherlands
/bin/cp Banish/Banish.nl.pl /var/ipcop/addon-lang/Banish.nl.pl

# Lang Script Cache Compliation
perl -e "require '//var/ipcop/lang.pl'; &Lang::BuildCacheLang" 

# Add network "whois" lookups
/bin/cat /home/httpd/cgi-bin/ipinfo.cgi |sed -e '/my.$whoisname/ r Banish/Banish_ipinfo.pl'>ipinfo.cgi.tmp
/usr/bin/perl -pi.old -e "s/addr \./address \./g" ipinfo.cgi.tmp 
/bin/cp ipinfo.cgi.tmp /home/httpd/cgi-bin/ipinfo.cgi

# Add firewall log tweak
/bin/cat /home/httpd/cgi-bin/logs.cgi/firewalllog.dat |sed -e '/my.$packet/ r Banish/Banish_firewalllog.pl'>firewalllog.dat.tmp
/bin/cp firewalllog.dat.tmp /home/httpd/cgi-bin/logs.cgi/firewalllog.dat

# Add system log tweak
/bin/cat /home/httpd/cgi-bin/logs.cgi/log.dat |sed -e '/pluto/ r Banish/Banish_log.pl'>log.dat.tmp
/bin/cat log.dat.tmp |sed -e '/IPSec/ r Banish/Banish_log2.pl'>log.dat.tmp2
/bin/cp log.dat.tmp2 /home/httpd/cgi-bin/logs.cgi/log.dat
echo "Done!"

# Add call to rc.Banish from rc.local
/bin/cat Banish/Banish_rc.local.sh >>/etc/rc.d/rc.local

# Run Banish
echo -e "Starting Banish......................\c"
/usr/local/bin/setBanish
echo "Done!"  

# Cleaning up
echo -e "Cleaning up..........................\c"
/bin/rm -rf *
cd ..
/bin/rm -rf /tmp/banish-1.4.7
echo -e  "Done!\n"

echo -e "\033[1;32mBanish Installation Complete \033[0m"
/usr/bin/logger -t "banish" "Banish-1.4.7 Installation Completed"
echo
echo -e  "To uninstall, run /usr/local/bin/uninstall_Banish.sh\n"
echo -e "\033[1;34mhttp://sidsolutions.net\n \033[0m"
echo -e "\033[1;33mPlease Donate\033[0m"
